Changelog
=========


1.0.0a2 (2018-07-20)
--------------------

- ``plone.oidc.membrane.behaviors.IOidConnectClaims`` behavior is available.
- ``oidc_membrane_user_workflow`` workflow is available.


1.0.0a1 (2018-07-20)
--------------------

- Initial release.
  [nazrulworld]
